use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/Robots/Validate.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/01-config.t',
    't/10-basic.t',
    't/11-cache.t',
    't/12-shared-hostname.t',
    't/13-multiple-domains.t',
    't/14-ipv6.t',
    't/15-forward-lookup-limit.t',
    't/16-resolver-failure.t',
    't/17-empty-domains-config.t',
    't/21-cache_failure-default.t'
);

notabs_ok($_) foreach @files;
done_testing;
